@@ -495,7 +495,7 @@ class DataframeType(BaseType):
     @type_operator(FIELD_DATAFRAME)
     def empty(self, other_value: dict):
         target = self.replace_prefix(other_value.get("target"))
-        results = np.where((self.value[target] == "" or pd.isnull(self[target])), True, False)
+        results = np.where(self.value[target].isin(["", None]), True, False)
         return pd.Series(results)
 
     @type_operator(FIELD_DATAFRAME)
@@ -505,7 +505,7 @@ class DataframeType(BaseType):
         # group all targets by comparator
         grouped_target = self.value.groupby(comparator)[target]
         # validate all targets except the last one
-        results = grouped_target.apply(lambda x: x[:-1]).apply(pd.isnull)
+        results = grouped_target.apply(lambda x: x[:-1]).apply(lambda x: x in ["", None])
         # extract values with corresponding indexes from results
         self.value[f"result_{uuid4()}"] = results.reset_index(level=0, drop=True)
         return True in results.values
@@ -521,7 +521,7 @@ class DataframeType(BaseType):
         # group all targets by comparator
         grouped_target = self.value.groupby(comparator)[target]
         # validate all targets except the last one
-        results = ~grouped_target.apply(lambda x: x[:-1]).apply(pd.isnull)
+        results = ~grouped_target.apply(lambda x: x[:-1]).apply(lambda x: x in ["", None])
         # extract values with corresponding indexes from results
         self.value[f"result_{uuid4()}"] = results.reset_index(level=0, drop=True)
         return not(False in results.values)
